#tested

import sqlite3

class top:
    def __init__(self, place:int):
        self.place = place
        
    def user_ID(self):
        offset = self.place - 1
        
        conn =  sqlite3.connect("economy.db")
        c = conn.cursor()
        
        c.execute(f"SELECT * FROM economy ORDER BY net DESC LIMIT 1 OFFSET {offset}")
        
        items = c.fetchall()
        
        for item in items:
            user_ID = int(item[0])
            
        return user_ID

    def wallet(self):
        offset = self.place - 1
        
        conn =  sqlite3.connect("economy.db")
        c = conn.cursor()
        
        c.execute(f"SELECT * FROM economy ORDER BY net DESC LIMIT 1 OFFSET {offset}")
        
        items = c.fetchall()
        
        for item in items:
            wallet = int(item[1])
            
        return wallet
        
    def bank(self):
        offset = self.place - 1
        
        conn =  sqlite3.connect("economy.db")
        c = conn.cursor()
        
        c.execute(f"SELECT * FROM economy ORDER BY net DESC LIMIT 1 OFFSET {offset}")
        
        items = c.fetchall()
        
        for item in items:
            bank = int(item[2])
            
        return bank
    
    def net(self):
        offset = self.place - 1
        
        conn =  sqlite3.connect("economy.db")
        c = conn.cursor()
        
        c.execute(f"SELECT * FROM economy ORDER BY net DESC LIMIT 1 OFFSET {offset}")
        
        items = c.fetchall()
        
        for item in items:
            net = int(item[3])
            
        return net


#not working

import inspect
import sqlite3
from inspect import getframeinfo
from inspect import stack


class view:
    def __init__(self, user_ID:int):
        self.user_ID = user_ID
        
    def wallet(self):                    
        conn = sqlite3.connect("economy.db")
        c = conn.cursor()
            
        c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
            
        items = c.fetchall()
        none = str(items)
            
        if none == "[]":
                return "0"
            
        else:
            for item in items:
                wallet = item[1]
                    
            return wallet        

    def bank(self):                    
        conn = sqlite3.connect("economy.db")
        c = conn.cursor()
            
        c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
            
        items = c.fetchall()
        none = str(items)
            
        if none == "[]":
                return "0"
            
        else:
            for item in items:
                bank = item[2]
                    
            return bank   
        
    def net(self):                    
        conn = sqlite3.connect("economy.db")
        c = conn.cursor()
            
        c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
            
        items = c.fetchall()
        none = str(items)
            
        if none == "[]":
                return "0"
            
        else:
            for item in items:
                net = item[3]
                    
            return net   



#tested  wallet class with adding and subtracting and it all worked:

import sqlite3

class wallet:
    def __init__(self, amount: int, user_ID):
        self.user_ID =  user_ID
        self.amount = amount
        
    def add(self):
        conn = sqlite3.connect("economy.db")
        c = conn.cursor()
        
        c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
        
        items = c.fetchall()
        none = str(items)
        
        if none == "[]":
            c.execute(f"INSERT INTO economy VALUES ({self.user_ID}, {self.amount} , 0, {self.amount})")
            
            conn.commit()
            conn.close()
            
        else:
            for item in items:
                wallet = int(item[1])
                bank = int(item[2])
                
            sum = self.amount + wallet
            
            c.execute(f"""UPDATE economy SET wallet = {sum}
                    WHERE user_ID = {self.user_ID}  
                """)
            
            conn.commit()
            
            net = sum + bank
            
            c.execute(f"""UPDATE economy SET net = {net}
                    WHERE user_ID = {self.user_ID}
                """)
            
            conn.commit()
            conn.close()
        
    def sub(self):
        conn = sqlite3.connect("economy.db")
        c = conn.cursor()
        
        c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
        
        items = c.fetchall()
        none = str(items)
        
        if none == "[]":
            c.execute(f"INSERT INTO economy VALUES ({self.user_ID}, 0 , 0, 0)")
            
            return None
        
        else:
            for item in items:
                wallet = int(item[1])
                bank = int(item[2])
                
            if wallet >= self.amount:
                sum = wallet - self.amount
                net = sum + bank
                
                c.execute(f"""UPDATE economy SET wallet = {sum}
                        WHERE user_ID = {self.user_ID}  
                    """)
                
                conn.commit()
                
                c.execute(f"""UPDATE economy SET net = {net}
                        WHERE user_ID = {self.user_ID}
                    """)
                
                conn.commit()
                conn.close()
            
            elif wallet < self.amount:
                return None
            
            else:
                return None


import sqlite3

class results:
    class view:
        def __init__(self, user_ID:int):
            self.user_ID = user_ID
            
        def wallet(self):                    
            conn = sqlite3.connect("economy.db")
            c = conn.cursor()
                
            c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
                
            items = c.fetchall()
            none = str(items)
                
            if none == "[]":
                    return "0"
                
            else:
                for item in items:
                    wallet = item[1]
                        
                return wallet        

        def bank(self):                    
            conn = sqlite3.connect("economy.db")
            c = conn.cursor()
                
            c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
                
            items = c.fetchall()
            none = str(items)
                
            if none == "[]":
                    return "0"
                
            else:
                for item in items:
                    bank = item[2]
                        
                return bank   
            
        def net(self):                    
            conn = sqlite3.connect("economy.db")
            c = conn.cursor()
                
            c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
                
            items = c.fetchall()
            none = str(items)
                
            if none == "[]":
                    return "0"
                
            else:
                for item in items:
                    net = item[3]
                        
                return net  
            
    class top:
        def __init__(self, place:int):
            self.place = place
            
        def user_ID(self):
            offset = self.place - 1
            
            conn =  sqlite3.connect("economy.db")
            c = conn.cursor()
            
            c.execute(f"SELECT * FROM economy ORDER BY net DESC LIMIT 1 OFFSET {offset}")
            
            items = c.fetchall()
            
            for item in items:
                user_ID = int(item[0])
                
            return user_ID

        def wallet(self):
            offset = self.place - 1
            
            conn =  sqlite3.connect("economy.db")
            c = conn.cursor()
            
            c.execute(f"SELECT * FROM economy ORDER BY net DESC LIMIT 1 OFFSET {offset}")
            
            items = c.fetchall()
            
            for item in items:
                wallet = int(item[1])
                
            return wallet
            
        def bank(self):
            offset = self.place - 1
            
            conn =  sqlite3.connect("economy.db")
            c = conn.cursor()
            
            c.execute(f"SELECT * FROM economy ORDER BY net DESC LIMIT 1 OFFSET {offset}")
            
            items = c.fetchall()
            
            for item in items:
                bank = int(item[2])
                
            return bank
        
        def net(self):
            offset = self.place - 1
            
            conn =  sqlite3.connect("economy.db")
            c = conn.cursor()
            
            c.execute(f"SELECT * FROM economy ORDER BY net DESC LIMIT 1 OFFSET {offset}")
            
            items = c.fetchall()
            
            for item in items:
                net = int(item[3])
                
            return net 



#tested and it worked

import sqlite3

def start():
    conn = sqlite3.connect("economy.db")
    c = conn.cursor()
    
    try:
        c.execute("""CREATE TABLE economy (
                user_ID int,
                wallet int,
                bank int,
                net int
                
        )""")
        
        pass
    
    except:
        print("table wrong")
        
    
    conn.commit()
    conn.close()


import sqlite3

class money:
    class wallet:
        def __init__(self, amount: int, user_ID):
            self.user_ID =  user_ID
            self.amount = amount
            
        def add(self):
            conn = sqlite3.connect("economy.db")
            c = conn.cursor()
            
            c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
            
            items = c.fetchall()
            none = str(items)
            
            if none == "[]":
                c.execute(f"INSERT INTO economy VALUES ({self.user_ID}, {self.amount} , 0, {self.amount})")
                
                conn.commit()
                conn.close()
                
            else:
                for item in items:
                    wallet = int(item[1])
                    bank = int(item[2])
                    
                sum = self.amount + wallet
                
                c.execute(f"""UPDATE economy SET wallet = {sum}
                        WHERE user_ID = {self.user_ID}  
                    """)
                
                conn.commit()
                
                net = sum + bank
                
                c.execute(f"""UPDATE economy SET net = {net}
                        WHERE user_ID = {self.user_ID}
                    """)
                
                conn.commit()
                conn.close()
            
        def sub(self):
            conn = sqlite3.connect("economy.db")
            c = conn.cursor()
            
            c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
            
            items = c.fetchall()
            none = str(items)
            
            if none == "[]":
                c.execute(f"INSERT INTO economy VALUES ({self.user_ID}, 0 , 0, 0)")
                
                return None
            
            else:
                for item in items:
                    wallet = int(item[1])
                    bank = int(item[2])
                    
                if wallet >= self.amount:
                    sum = wallet - self.amount
                    net = sum + bank
                    
                    c.execute(f"""UPDATE economy SET wallet = {sum}
                            WHERE user_ID = {self.user_ID}  
                        """)
                    
                    conn.commit()
                    
                    c.execute(f"""UPDATE economy SET net = {net}
                            WHERE user_ID = {self.user_ID}
                        """)
                    
                    conn.commit()
                    conn.close()
                
                elif wallet < self.amount:
                    sum = wallet - self.amount
                    net = sum + bank
                    
                    c.execute(f"""UPDATE economy SET wallet = {sum}
                                    WHERE user_ID = {self.user_ID}
                            """)
                    
                    conn.commit()
                    
                    c.execute(f"""UPDATE economy SET net = {net}
                                WHERE user_ID = {self.user_ID}
                        """)
                    
                    conn.commit()
                    conn.close()
                
                else:
                    return None
            
    class bank:
        def __init__(self, amount: int, user_ID):
            self.user_ID =  user_ID
            self.amount = amount
            
        def add(self):
            conn = sqlite3.connect("economy.db")
            c = conn.cursor()
            
            c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
            
            items = c.fetchall()
            none = str(items)
            
            if none == "[]":
                c.execute(f"INSERT INTO economy VALUES ({self.user_ID}, 0 , {self.amount}, {self.amount})")
                
                conn.commit()
                conn.close()
                
            else:
                for item in items:
                    wallet = int(item[1])
                    bank = int(item[2])
                    
                sum = self.amount + bank
                
                c.execute(f"""UPDATE economy SET bank = {sum}
                        WHERE user_ID = {self.user_ID}  
                    """)
                
                conn.commit()
                
                net = sum + wallet
                
                c.execute(f"""UPDATE economy SET net = {net}
                        WHERE user_ID = {self.user_ID}
                    """)
                
                conn.commit()
                conn.close()
            
        def sub(self):
            conn = sqlite3.connect("economy.db")
            c = conn.cursor()
            
            c.execute(f"SELECT * FROM economy WHERE user_ID={self.user_ID}")
            
            items = c.fetchall()
            none = str(items)
            
            if none == "[]":
                c.execute(f"INSERT INTO economy VALUES ({self.user_ID}, 0 , 0, 0)")
                
                return None
            
            else:
                for item in items:
                    wallet = int(item[1])
                    bank = int(item[2])
                    
                if bank >= self.amount:
                    sum = bank - self.amount
                    net = sum + wallet
                    
                    c.execute(f"""UPDATE economy SET bank = {sum}
                            WHERE user_ID = {self.user_ID}  
                        """)
                    
                    conn.commit()
                    
                    c.execute(f"""UPDATE economy SET net = {net}
                            WHERE user_ID = {self.user_ID}
                        """)
                    
                    conn.commit()
                    conn.close()
                
                elif bank < self.amount:
                    sum = bank - self.amount
                    net = sum + wallet
                    
                    c.execute(f"""UPDATE economy SET bank = {sum}
                                    WHERE user_ID = {self.user_ID}
                            """)
                    
                    conn.commit()
                    
                    c.execute(f"""UPDATE economy SET net = {net}
                                WHERE user_ID = {self.user_ID}
                        """)
                    
                    conn.commit()
                    conn.close()
                
                else:
                    return None


from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()
readme = (here / 'README.md').read_text(encoding='utf-8')

classifiers = [
  'Development Status :: 4 - Beta',
  'Intended Audience :: Developers',
  'Operating System :: OS Independent',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='Disecon',
  version='0.6.10',
  description='Disecon',
  long_description=readme,
  long_description_content_type="text/markdown",
  url='',  
  author='LegosAndStuff',
  license='MIT', 
  classifiers=classifiers,
  keywords='economy', 
  packages=find_packages(),
  install_requires=[''] 
)